@@ -917,3 +917,49 @@ class GcpDataflowJob(GoogleAPIResource):
             'location': self._resource_data['location'],
             'view': 'JOB_VIEW_DESCRIPTION'
         }
+
+class GcpRedisInstance(GoogleAPIResource):
+
+    service_name = "redis"
+    resource_path = "projects.locations.instances"
+    version = "v1"
+
+    readiness_key = 'state'
+    readiness_value = 'READY'
+    readiness_terminal_values = ['DELETING', 'STATE_UNSPECIFIED']
+
+    required_resource_data = ['name', 'project_id', 'location']
+
+    resource_type = 'redis.googleapis.com/Instance'
+
+    def _get_request_args(self):
+        return {
+            'name': 'projects/{}/locations/{}/instances/{}'.format(
+                self._resource_data['project_id'],
+                self._resource_data['location'],
+                self._resource_data['name']
+            ),
+        }
+
+class GcpMemcacheInstance(GoogleAPIResource):
+
+    service_name = "memcache"
+    resource_path = "projects.locations.instances"
+    version = "v1"
+
+    readiness_key = 'state'
+    readiness_value = 'READY'
+    readiness_terminal_values = ['DELETING', 'STATE_UNSPECIFIED']
+
+    required_resource_data = ['name', 'project_id', 'location']
+
+    resource_type = 'memcache.googleapis.com/Instance'
+
+    def _get_request_args(self):
+        return {
+            'name': 'projects/{}/locations/{}/instances/{}'.format(
+                self._resource_data['project_id'],
+                self._resource_data['location'],
+                self._resource_data['name']
+            ),
+        }
